@@ -48,6 +48,10 @@ from basic_memory.schemas.directory import (
     DirectoryNode,
 )
 
+from basic_memory.schemas.sync_report import (
+    SyncReportResponse,
+)
+
 # For convenient imports, export all models
 __all__ = [
     # Base
@@ -77,4 +81,6 @@ __all__ = [
     "ProjectInfoResponse",
     # Directory
     "DirectoryNode",
+    # Sync
+    "SyncReportResponse",
 ]
