@@ -9,7 +9,7 @@ from fastmcp import Client
 
 
 @pytest.mark.asyncio
-async def test_move_note_basic_operation(mcp_server, app):
+async def test_move_note_basic_operation(mcp_server, app, test_project):
     """Test basic move note operation to a new folder."""
 
     async with Client(mcp_server) as client:
@@ -17,6 +17,7 @@ async def test_move_note_basic_operation(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Move Test Note",
                 "folder": "source",
                 "content": "# Move Test Note\n\nThis note will be moved to a new location.",
@@ -28,14 +29,15 @@ async def test_move_note_basic_operation(mcp_server, app):
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Move Test Note",
                 "destination_path": "destination/moved-note.md",
             },
         )
 
         # Should return successful move message
-        assert len(move_result) == 1
-        move_text = move_result[0].text
+        assert len(move_result.content) == 1
+        move_text = move_result.content[0].text
         assert "✅ Note moved successfully" in move_text
         assert "Move Test Note" in move_text
         assert "destination/moved-note.md" in move_text
@@ -45,27 +47,29 @@ async def test_move_note_basic_operation(mcp_server, app):
         read_result = await client.call_tool(
             "read_note",
             {
+                "project": test_project.name,
                 "identifier": "destination/moved-note.md",
             },
         )
 
-        content = read_result[0].text
+        content = read_result.content[0].text
         assert "This note will be moved to a new location" in content
 
         # Verify the original location no longer works
         read_original = await client.call_tool(
             "read_note",
             {
+                "project": test_project.name,
                 "identifier": "source/move-test-note.md",
             },
         )
 
         # Should return "Note Not Found" message
-        assert "Note Not Found" in read_original[0].text
+        assert "Note Not Found" in read_original.content[0].text
 
 
 @pytest.mark.asyncio
-async def test_move_note_using_permalink(mcp_server, app):
+async def test_move_note_using_permalink(mcp_server, app, test_project):
     """Test moving a note using its permalink as identifier."""
 
     async with Client(mcp_server) as client:
@@ -73,6 +77,7 @@ async def test_move_note_using_permalink(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Permalink Move Test",
                 "folder": "test",
                 "content": "# Permalink Move Test\n\nMoving by permalink.",
@@ -84,14 +89,15 @@ async def test_move_note_using_permalink(mcp_server, app):
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "test/permalink-move-test",
                 "destination_path": "archive/permalink-moved.md",
             },
         )
 
         # Should successfully move
-        assert len(move_result) == 1
-        move_text = move_result[0].text
+        assert len(move_result.content) == 1
+        move_text = move_result.content[0].text
         assert "✅ Note moved successfully" in move_text
         assert "test/permalink-move-test" in move_text
         assert "archive/permalink-moved.md" in move_text
@@ -100,15 +106,16 @@ async def test_move_note_using_permalink(mcp_server, app):
         read_result = await client.call_tool(
             "read_note",
             {
+                "project": test_project.name,
                 "identifier": "archive/permalink-moved.md",
             },
         )
 
-        assert "Moving by permalink" in read_result[0].text
+        assert "Moving by permalink" in read_result.content[0].text
 
 
 @pytest.mark.asyncio
-async def test_move_note_with_observations_and_relations(mcp_server, app):
+async def test_move_note_with_observations_and_relations(mcp_server, app, test_project):
     """Test moving a note that contains observations and relations."""
 
     async with Client(mcp_server) as client:
@@ -133,6 +140,7 @@ This note demonstrates moving complex content."""
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Complex Note",
                 "folder": "complex",
                 "content": complex_content,
@@ -144,14 +152,15 @@ This note demonstrates moving complex content."""
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Complex Note",
                 "destination_path": "moved/complex-note.md",
             },
         )
 
         # Should successfully move
-        assert len(move_result) == 1
-        move_text = move_result[0].text
+        assert len(move_result.content) == 1
+        move_text = move_result.content[0].text
         assert "✅ Note moved successfully" in move_text
         assert "Complex Note" in move_text
         assert "moved/complex-note.md" in move_text
@@ -160,11 +169,12 @@ This note demonstrates moving complex content."""
         read_result = await client.call_tool(
             "read_note",
             {
+                "project": test_project.name,
                 "identifier": "moved/complex-note.md",
             },
         )
 
-        content = read_result[0].text
+        content = read_result.content[0].text
         assert "Has structured observations" in content
         assert "implements [[Auth System]]" in content
         assert "## Observations" in content
@@ -173,7 +183,7 @@ This note demonstrates moving complex content."""
 
 
 @pytest.mark.asyncio
-async def test_move_note_to_nested_directory(mcp_server, app):
+async def test_move_note_to_nested_directory(mcp_server, app, test_project):
     """Test moving a note to a deeply nested directory structure."""
 
     async with Client(mcp_server) as client:
@@ -181,6 +191,7 @@ async def test_move_note_to_nested_directory(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Nested Move Test",
                 "folder": "root",
                 "content": "# Nested Move Test\n\nThis will be moved deep.",
@@ -192,14 +203,15 @@ async def test_move_note_to_nested_directory(mcp_server, app):
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Nested Move Test",
                 "destination_path": "projects/2025/q2/work/nested-note.md",
             },
         )
 
         # Should successfully create directory structure and move
-        assert len(move_result) == 1
-        move_text = move_result[0].text
+        assert len(move_result.content) == 1
+        move_text = move_result.content[0].text
         assert "✅ Note moved successfully" in move_text
         assert "Nested Move Test" in move_text
         assert "projects/2025/q2/work/nested-note.md" in move_text
@@ -208,15 +220,16 @@ async def test_move_note_to_nested_directory(mcp_server, app):
         read_result = await client.call_tool(
             "read_note",
             {
+                "project": test_project.name,
                 "identifier": "projects/2025/q2/work/nested-note.md",
             },
         )
 
-        assert "This will be moved deep" in read_result[0].text
+        assert "This will be moved deep" in read_result.content[0].text
 
 
 @pytest.mark.asyncio
-async def test_move_note_with_special_characters(mcp_server, app):
+async def test_move_note_with_special_characters(mcp_server, app, test_project):
     """Test moving notes with special characters in titles and paths."""
 
     async with Client(mcp_server) as client:
@@ -224,6 +237,7 @@ async def test_move_note_with_special_characters(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Special (Chars) & Symbols",
                 "folder": "special",
                 "content": "# Special (Chars) & Symbols\n\nTesting special characters in move.",
@@ -235,14 +249,15 @@ async def test_move_note_with_special_characters(mcp_server, app):
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Special (Chars) & Symbols",
                 "destination_path": "archive/special-chars-note.md",
             },
         )
 
         # Should handle special characters properly
-        assert len(move_result) == 1
-        move_text = move_result[0].text
+        assert len(move_result.content) == 1
+        move_text = move_result.content[0].text
         assert "✅ Note moved successfully" in move_text
         assert "archive/special-chars-note.md" in move_text
 
@@ -250,15 +265,16 @@ async def test_move_note_with_special_characters(mcp_server, app):
         read_result = await client.call_tool(
             "read_note",
             {
+                "project": test_project.name,
                 "identifier": "archive/special-chars-note.md",
             },
         )
 
-        assert "Testing special characters in move" in read_result[0].text
+        assert "Testing special characters in move" in read_result.content[0].text
 
 
 @pytest.mark.asyncio
-async def test_move_note_error_handling_note_not_found(mcp_server, app):
+async def test_move_note_error_handling_note_not_found(mcp_server, app, test_project):
     """Test error handling when trying to move a non-existent note."""
 
     async with Client(mcp_server) as client:
@@ -266,20 +282,21 @@ async def test_move_note_error_handling_note_not_found(mcp_server, app):
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Non-existent Note",
                 "destination_path": "new/location.md",
             },
         )
 
         # Should contain error message about the failed operation
-        assert len(move_result) == 1
-        error_message = move_result[0].text
+        assert len(move_result.content) == 1
+        error_message = move_result.content[0].text
         assert "# Move Failed" in error_message
         assert "Non-existent Note" in error_message
 
 
 @pytest.mark.asyncio
-async def test_move_note_error_handling_invalid_destination(mcp_server, app):
+async def test_move_note_error_handling_invalid_destination(mcp_server, app, test_project):
     """Test error handling for invalid destination paths."""
 
     async with Client(mcp_server) as client:
@@ -287,6 +304,7 @@ async def test_move_note_error_handling_invalid_destination(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Invalid Dest Test",
                 "folder": "test",
                 "content": "# Invalid Dest Test\n\nThis move should fail.",
@@ -298,20 +316,21 @@ async def test_move_note_error_handling_invalid_destination(mcp_server, app):
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Invalid Dest Test",
                 "destination_path": "/absolute/path/note.md",
             },
         )
 
         # Should contain error message about the failed operation
-        assert len(move_result) == 1
-        error_message = move_result[0].text
+        assert len(move_result.content) == 1
+        error_message = move_result.content[0].text
         assert "# Move Failed" in error_message
         assert "/absolute/path/note.md" in error_message
 
 
 @pytest.mark.asyncio
-async def test_move_note_error_handling_destination_exists(mcp_server, app):
+async def test_move_note_error_handling_destination_exists(mcp_server, app, test_project):
     """Test error handling when destination file already exists."""
 
     async with Client(mcp_server) as client:
@@ -319,6 +338,7 @@ async def test_move_note_error_handling_destination_exists(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Source Note",
                 "folder": "source",
                 "content": "# Source Note\n\nThis is the source.",
@@ -330,6 +350,7 @@ async def test_move_note_error_handling_destination_exists(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Existing Note",
                 "folder": "destination",
                 "content": "# Existing Note\n\nThis already exists.",
@@ -341,20 +362,21 @@ async def test_move_note_error_handling_destination_exists(mcp_server, app):
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Source Note",
                 "destination_path": "destination/Existing Note.md",  # Use exact existing file name
             },
         )
 
         # Should contain error message about the failed operation
-        assert len(move_result) == 1
-        error_message = move_result[0].text
+        assert len(move_result.content) == 1
+        error_message = move_result.content[0].text
         assert "# Move Failed" in error_message
         assert "already exists" in error_message
 
 
 @pytest.mark.asyncio
-async def test_move_note_preserves_search_functionality(mcp_server, app):
+async def test_move_note_preserves_search_functionality(mcp_server, app, test_project):
     """Test that moved notes remain searchable after move operation."""
 
     async with Client(mcp_server) as client:
@@ -362,13 +384,14 @@ async def test_move_note_preserves_search_functionality(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Searchable Note",
                 "folder": "original",
                 "content": """# Searchable Note
 
 This note contains unique search terms:
 - quantum mechanics
-- artificial intelligence 
+- artificial intelligence
 - machine learning algorithms
 
 ## Features
@@ -385,36 +408,39 @@ This note contains unique search terms:
         search_before = await client.call_tool(
             "search_notes",
             {
+                "project": test_project.name,
                 "query": "quantum mechanics",
             },
         )
 
-        assert len(search_before) > 0
-        assert "Searchable Note" in search_before[0].text
+        assert len(search_before.content) > 0
+        assert "Searchable Note" in search_before.content[0].text
 
         # Move the note
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Searchable Note",
                 "destination_path": "research/quantum-ai-note.md",
             },
         )
 
-        assert len(move_result) == 1
-        move_text = move_result[0].text
+        assert len(move_result.content) == 1
+        move_text = move_result.content[0].text
         assert "✅ Note moved successfully" in move_text
 
         # Verify note is still searchable after move
         search_after = await client.call_tool(
             "search_notes",
             {
+                "project": test_project.name,
                 "query": "quantum mechanics",
             },
         )
 
-        assert len(search_after) > 0
-        search_text = search_after[0].text
+        assert len(search_after.content) > 0
+        search_text = search_after.content[0].text
         assert "quantum mechanics" in search_text
         assert "research/quantum-ai-note.md" in search_text or "quantum-ai-note" in search_text
 
@@ -422,15 +448,16 @@ This note contains unique search terms:
         search_by_path = await client.call_tool(
             "search_notes",
             {
+                "project": test_project.name,
                 "query": "research/quantum",
             },
         )
 
-        assert len(search_by_path) > 0
+        assert len(search_by_path.content) > 0
 
 
 @pytest.mark.asyncio
-async def test_move_note_using_different_identifier_formats(mcp_server, app):
+async def test_move_note_using_different_identifier_formats(mcp_server, app, test_project):
     """Test moving notes using different identifier formats (title, permalink, folder/title)."""
 
     async with Client(mcp_server) as client:
@@ -438,6 +465,7 @@ async def test_move_note_using_different_identifier_formats(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Title ID Note",
                 "folder": "test",
                 "content": "# Title ID Note\n\nMove by title.",
@@ -448,6 +476,7 @@ async def test_move_note_using_different_identifier_formats(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Permalink ID Note",
                 "folder": "test",
                 "content": "# Permalink ID Note\n\nMove by permalink.",
@@ -458,6 +487,7 @@ async def test_move_note_using_different_identifier_formats(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Folder Title Note",
                 "folder": "test",
                 "content": "# Folder Title Note\n\nMove by folder/title.",
@@ -469,48 +499,57 @@ async def test_move_note_using_different_identifier_formats(mcp_server, app):
         move1 = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Title ID Note",  # by title
                 "destination_path": "moved/title-moved.md",
             },
         )
-        assert len(move1) == 1
-        assert "✅ Note moved successfully" in move1[0].text
+        assert len(move1.content) == 1
+        assert "✅ Note moved successfully" in move1.content[0].text
 
         # Test moving by permalink
         move2 = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "test/permalink-id-note",  # by permalink
                 "destination_path": "moved/permalink-moved.md",
             },
         )
-        assert len(move2) == 1
-        assert "✅ Note moved successfully" in move2[0].text
+        assert len(move2.content) == 1
+        assert "✅ Note moved successfully" in move2.content[0].text
 
         # Test moving by folder/title format
         move3 = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "test/Folder Title Note",  # by folder/title
                 "destination_path": "moved/folder-title-moved.md",
             },
         )
-        assert len(move3) == 1
-        assert "✅ Note moved successfully" in move3[0].text
+        assert len(move3.content) == 1
+        assert "✅ Note moved successfully" in move3.content[0].text
 
         # Verify all notes can be accessed at their new locations
-        read1 = await client.call_tool("read_note", {"identifier": "moved/title-moved.md"})
-        assert "Move by title" in read1[0].text
+        read1 = await client.call_tool(
+            "read_note", {"project": test_project.name, "identifier": "moved/title-moved.md"}
+        )
+        assert "Move by title" in read1.content[0].text
 
-        read2 = await client.call_tool("read_note", {"identifier": "moved/permalink-moved.md"})
-        assert "Move by permalink" in read2[0].text
+        read2 = await client.call_tool(
+            "read_note", {"project": test_project.name, "identifier": "moved/permalink-moved.md"}
+        )
+        assert "Move by permalink" in read2.content[0].text
 
-        read3 = await client.call_tool("read_note", {"identifier": "moved/folder-title-moved.md"})
-        assert "Move by folder/title" in read3[0].text
+        read3 = await client.call_tool(
+            "read_note", {"project": test_project.name, "identifier": "moved/folder-title-moved.md"}
+        )
+        assert "Move by folder/title" in read3.content[0].text
 
 
 @pytest.mark.asyncio
-async def test_move_note_cross_project_detection(mcp_server, app):
+async def test_move_note_cross_project_detection(mcp_server, app, test_project):
     """Test cross-project move detection and helpful error messages."""
 
     async with Client(mcp_server) as client:
@@ -528,6 +567,7 @@ async def test_move_note_cross_project_detection(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Cross Project Test Note",
                 "folder": "source",
                 "content": "# Cross Project Test Note\n\nThis note is in the default project.",
@@ -539,67 +579,23 @@ async def test_move_note_cross_project_detection(mcp_server, app):
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Cross Project Test Note",
                 "destination_path": "test-project-b/moved-note.md",
             },
         )
 
         # Should detect cross-project attempt and provide helpful guidance
-        assert len(move_result) == 1
-        error_message = move_result[0].text
+        assert len(move_result.content) == 1
+        error_message = move_result.content[0].text
         assert "Cross-Project Move Not Supported" in error_message
         assert "test-project-b" in error_message
-        assert "switch_project" in error_message
         assert "read_note" in error_message
         assert "write_note" in error_message
 
 
 @pytest.mark.asyncio
-async def test_move_note_potential_cross_project_guidance(mcp_server, app):
-    """Test guidance for potentially cross-project moves with project-like keywords."""
-
-    async with Client(mcp_server) as client:
-        # Create another test project
-        await client.call_tool(
-            "create_memory_project",
-            {
-                "project_name": "workspace-docs",
-                "project_path": "/tmp/workspace-docs",
-                "set_default": False,
-            },
-        )
-
-        # Create a note in the default project
-        await client.call_tool(
-            "write_note",
-            {
-                "title": "Potential Cross Project Note",
-                "folder": "source",
-                "content": "# Potential Cross Project Note\n\nThis might be moved cross-project.",
-                "tags": "test,potential-cross-project",
-            },
-        )
-
-        # Try to move to a path that contains project-like keywords but not exact project names
-        move_result = await client.call_tool(
-            "move_note",
-            {
-                "identifier": "Potential Cross Project Note",
-                "destination_path": "project-archive/moved-note.md",
-            },
-        )
-
-        # Should provide guidance for potential cross-project moves
-        assert len(move_result) == 1
-        error_message = move_result[0].text
-        assert "Check Project Context" in error_message
-        assert "workspace-docs" in error_message  # Should mention other available projects
-        assert "list_projects" in error_message
-        assert "switch_project" in error_message
-
-
-@pytest.mark.asyncio
-async def test_move_note_normal_moves_still_work(mcp_server, app):
+async def test_move_note_normal_moves_still_work(mcp_server, app, test_project):
     """Test that normal within-project moves still work after cross-project detection."""
 
     async with Client(mcp_server) as client:
@@ -607,6 +603,7 @@ async def test_move_note_normal_moves_still_work(mcp_server, app):
         await client.call_tool(
             "write_note",
             {
+                "project": test_project.name,
                 "title": "Normal Move Note",
                 "folder": "source",
                 "content": "# Normal Move Note\n\nThis should move normally.",
@@ -618,14 +615,15 @@ async def test_move_note_normal_moves_still_work(mcp_server, app):
         move_result = await client.call_tool(
             "move_note",
             {
+                "project": test_project.name,
                 "identifier": "Normal Move Note",
                 "destination_path": "destination/normal-moved.md",
             },
         )
 
         # Should work normally
-        assert len(move_result) == 1
-        move_text = move_result[0].text
+        assert len(move_result.content) == 1
+        move_text = move_result.content[0].text
         assert "✅ Note moved successfully" in move_text
         assert "Normal Move Note" in move_text
         assert "destination/normal-moved.md" in move_text
@@ -634,9 +632,10 @@ async def test_move_note_normal_moves_still_work(mcp_server, app):
         read_result = await client.call_tool(
             "read_note",
             {
+                "project": test_project.name,
                 "identifier": "destination/normal-moved.md",
             },
         )
 
-        content = read_result[0].text
+        content = read_result.content[0].text
         assert "This should move normally" in content
