@@ -7,14 +7,15 @@ from pathlib import Path
 import pytest
 
 from basic_memory.schemas import EntityResponse
+from basic_memory.utils import normalize_newlines
 
 
 @pytest.mark.asyncio
-async def test_get_resource_content(client, test_config, entity_repository):
+async def test_get_resource_content(client, project_config, entity_repository, project_url):
     """Test getting content by permalink."""
     # Create a test file
     content = "# Test Content\n\nThis is a test file."
-    test_file = Path(test_config.home) / "test" / "test.md"
+    test_file = Path(project_config.home) / "test" / "test.md"
     test_file.parent.mkdir(parents=True, exist_ok=True)
     test_file.write_text(content)
 
@@ -32,18 +33,18 @@ async def test_get_resource_content(client, test_config, entity_repository):
     )
 
     # Test getting the content
-    response = await client.get(f"/resource/{entity.permalink}")
+    response = await client.get(f"{project_url}/resource/{entity.permalink}")
     assert response.status_code == 200
     assert response.headers["content-type"] == "text/markdown; charset=utf-8"
-    assert response.text == content
+    assert response.text == normalize_newlines(content)
 
 
 @pytest.mark.asyncio
-async def test_get_resource_pagination(client, test_config, entity_repository):
+async def test_get_resource_pagination(client, project_config, entity_repository, project_url):
     """Test getting content by permalink with pagination."""
     # Create a test file
     content = "# Test Content\n\nThis is a test file."
-    test_file = Path(test_config.home) / "test" / "test.md"
+    test_file = Path(project_config.home) / "test" / "test.md"
     test_file.parent.mkdir(parents=True, exist_ok=True)
     test_file.write_text(content)
 
@@ -61,18 +62,20 @@ async def test_get_resource_pagination(client, test_config, entity_repository):
     )
 
     # Test getting the content
-    response = await client.get(f"/resource/{entity.permalink}", params={"page": 1, "page_size": 1})
+    response = await client.get(
+        f"{project_url}/resource/{entity.permalink}", params={"page": 1, "page_size": 1}
+    )
     assert response.status_code == 200
     assert response.headers["content-type"] == "text/markdown; charset=utf-8"
-    assert response.text == content
+    assert response.text == normalize_newlines(content)
 
 
 @pytest.mark.asyncio
-async def test_get_resource_by_title(client, test_config, entity_repository):
+async def test_get_resource_by_title(client, project_config, entity_repository, project_url):
     """Test getting content by permalink."""
     # Create a test file
     content = "# Test Content\n\nThis is a test file."
-    test_file = Path(test_config.home) / "test" / "test.md"
+    test_file = Path(project_config.home) / "test" / "test.md"
     test_file.parent.mkdir(parents=True, exist_ok=True)
     test_file.write_text(content)
 
@@ -90,20 +93,20 @@ async def test_get_resource_by_title(client, test_config, entity_repository):
     )
 
     # Test getting the content
-    response = await client.get(f"/resource/{entity.title}")
+    response = await client.get(f"{project_url}/resource/{entity.title}")
     assert response.status_code == 200
 
 
 @pytest.mark.asyncio
-async def test_get_resource_missing_entity(client):
+async def test_get_resource_missing_entity(client, project_url):
     """Test 404 when entity doesn't exist."""
-    response = await client.get("/resource/does/not/exist")
+    response = await client.get(f"{project_url}/resource/does/not/exist")
     assert response.status_code == 404
     assert "Resource not found" in response.json()["detail"]
 
 
 @pytest.mark.asyncio
-async def test_get_resource_missing_file(client, test_config, entity_repository):
+async def test_get_resource_missing_file(client, project_config, entity_repository, project_url):
     """Test 404 when file doesn't exist."""
     # Create entity referencing non-existent file
     entity = await entity_repository.create(
@@ -118,13 +121,13 @@ async def test_get_resource_missing_file(client, test_config, entity_repository)
         }
     )
 
-    response = await client.get(f"/resource/{entity.permalink}")
+    response = await client.get(f"{project_url}/resource/{entity.permalink}")
     assert response.status_code == 404
     assert "File not found" in response.json()["detail"]
 
 
 @pytest.mark.asyncio
-async def test_get_resource_observation(client, test_config, entity_repository):
+async def test_get_resource_observation(client, project_config, entity_repository, project_url):
     """Test getting content by observation permalink."""
     # Create entity
     content = "# Test Content\n\n- [note] an observation."
@@ -134,7 +137,7 @@ async def test_get_resource_observation(client, test_config, entity_repository):
         "entity_type": "test",
         "content": f"{content}",
     }
-    response = await client.post("/knowledge/entities", json=data)
+    response = await client.post(f"{project_url}/knowledge/entities", json=data)
     entity_response = response.json()
     entity = EntityResponse(**entity_response)
 
@@ -142,11 +145,12 @@ async def test_get_resource_observation(client, test_config, entity_repository):
     observation = entity.observations[0]
 
     # Test getting the content via the observation
-    response = await client.get(f"/resource/{observation.permalink}")
+    response = await client.get(f"{project_url}/resource/{observation.permalink}")
     assert response.status_code == 200
     assert response.headers["content-type"] == "text/markdown; charset=utf-8"
     assert (
-        """
+        normalize_newlines(
+            """
 ---
 title: Test Entity
 type: test
@@ -157,12 +161,13 @@ permalink: test/test-entity
 
 - [note] an observation.
     """.strip()
+        )
         in response.text
     )
 
 
 @pytest.mark.asyncio
-async def test_get_resource_entities(client, test_config, entity_repository):
+async def test_get_resource_entities(client, project_config, entity_repository, project_url):
     """Test getting content by permalink match."""
     # Create entity
     content1 = "# Test Content\n"
@@ -172,7 +177,7 @@ async def test_get_resource_entities(client, test_config, entity_repository):
         "entity_type": "test",
         "content": f"{content1}",
     }
-    response = await client.post("/knowledge/entities", json=data)
+    response = await client.post(f"{project_url}/knowledge/entities", json=data)
     entity_response = response.json()
     entity1 = EntityResponse(**entity_response)
 
@@ -183,18 +188,19 @@ async def test_get_resource_entities(client, test_config, entity_repository):
         "entity_type": "test",
         "content": f"{content2}",
     }
-    response = await client.post("/knowledge/entities", json=data)
+    response = await client.post(f"{project_url}/knowledge/entities", json=data)
     entity_response = response.json()
     entity2 = EntityResponse(**entity_response)
 
     assert len(entity2.relations) == 1
 
     # Test getting the content via the relation
-    response = await client.get("/resource/test/*")
+    response = await client.get(f"{project_url}/resource/test/*")
     assert response.status_code == 200
     assert response.headers["content-type"] == "text/markdown; charset=utf-8"
     assert (
-        f"""
+        normalize_newlines(
+            f"""
 --- memory://test/test-entity {entity1.updated_at.isoformat()} {entity1.checksum[:8]}
 
 # Test Content
@@ -205,12 +211,15 @@ async def test_get_resource_entities(client, test_config, entity_repository):
 - links to [[Test Entity]]
 
     """.strip()
+        )
         in response.text
     )
 
 
 @pytest.mark.asyncio
-async def test_get_resource_entities_pagination(client, test_config, entity_repository):
+async def test_get_resource_entities_pagination(
+    client, project_config, entity_repository, project_url
+):
     """Test getting content by permalink match."""
     # Create entity
     content1 = "# Test Content\n"
@@ -220,7 +229,7 @@ async def test_get_resource_entities_pagination(client, test_config, entity_repo
         "entity_type": "test",
         "content": f"{content1}",
     }
-    response = await client.post("/knowledge/entities", json=data)
+    response = await client.post(f"{project_url}/knowledge/entities", json=data)
     entity_response = response.json()
     entity1 = EntityResponse(**entity_response)
     assert entity1
@@ -232,18 +241,21 @@ async def test_get_resource_entities_pagination(client, test_config, entity_repo
         "entity_type": "test",
         "content": f"{content2}",
     }
-    response = await client.post("/knowledge/entities", json=data)
+    response = await client.post(f"{project_url}/knowledge/entities", json=data)
     entity_response = response.json()
     entity2 = EntityResponse(**entity_response)
 
     assert len(entity2.relations) == 1
 
     # Test getting second result
-    response = await client.get("/resource/test/*", params={"page": 2, "page_size": 1})
+    response = await client.get(
+        f"{project_url}/resource/test/*", params={"page": 2, "page_size": 1}
+    )
     assert response.status_code == 200
     assert response.headers["content-type"] == "text/markdown; charset=utf-8"
     assert (
-        """
+        normalize_newlines(
+            """
 ---
 title: Related Entity
 type: test
@@ -253,12 +265,13 @@ permalink: test/related-entity
 # Related Content
 - links to [[Test Entity]]
 """.strip()
+        )
         in response.text
     )
 
 
 @pytest.mark.asyncio
-async def test_get_resource_relation(client, test_config, entity_repository):
+async def test_get_resource_relation(client, project_config, entity_repository, project_url):
     """Test getting content by relation permalink."""
     # Create entity
     content1 = "# Test Content\n"
@@ -268,7 +281,7 @@ async def test_get_resource_relation(client, test_config, entity_repository):
         "entity_type": "test",
         "content": f"{content1}",
     }
-    response = await client.post("/knowledge/entities", json=data)
+    response = await client.post(f"{project_url}/knowledge/entities", json=data)
     entity_response = response.json()
     entity1 = EntityResponse(**entity_response)
 
@@ -279,7 +292,7 @@ async def test_get_resource_relation(client, test_config, entity_repository):
         "entity_type": "test",
         "content": f"{content2}",
     }
-    response = await client.post("/knowledge/entities", json=data)
+    response = await client.post(f"{project_url}/knowledge/entities", json=data)
     entity_response = response.json()
     entity2 = EntityResponse(**entity_response)
 
@@ -287,11 +300,12 @@ async def test_get_resource_relation(client, test_config, entity_repository):
     relation = entity2.relations[0]
 
     # Test getting the content via the relation
-    response = await client.get(f"/resource/{relation.permalink}")
+    response = await client.get(f"{project_url}/resource/{relation.permalink}")
     assert response.status_code == 200
     assert response.headers["content-type"] == "text/markdown; charset=utf-8"
     assert (
-        f"""
+        normalize_newlines(
+            f"""
 --- memory://test/test-entity {entity1.updated_at.isoformat()} {entity1.checksum[:8]}
 
 # Test Content
@@ -302,12 +316,15 @@ async def test_get_resource_relation(client, test_config, entity_repository):
 - links to [[Test Entity]]
     
     """.strip()
+        )
         in response.text
     )
 
 
 @pytest.mark.asyncio
-async def test_put_resource_new_file(client, test_config, entity_repository, search_repository):
+async def test_put_resource_new_file(
+    client, project_config, entity_repository, search_repository, project_url
+):
     """Test creating a new file via PUT."""
     # Test data
     file_path = "visualizations/test.canvas"
@@ -327,12 +344,14 @@ async def test_put_resource_new_file(client, test_config, entity_repository, sea
     }
 
     # Make sure the file doesn't exist yet
-    full_path = Path(test_config.home) / file_path
+    full_path = Path(project_config.home) / file_path
     if full_path.exists():
         full_path.unlink()
 
     # Execute PUT request
-    response = await client.put(f"/resource/{file_path}", json=json.dumps(canvas_data, indent=2))
+    response = await client.put(
+        f"{project_url}/resource/{file_path}", json=json.dumps(canvas_data, indent=2)
+    )
 
     # Verify response
     assert response.status_code == 201
@@ -342,7 +361,7 @@ async def test_put_resource_new_file(client, test_config, entity_repository, sea
     assert "size" in response_data
 
     # Verify file was created
-    full_path = Path(test_config.home) / file_path
+    full_path = Path(project_config.home) / file_path
     assert full_path.exists()
 
     # Verify file content
@@ -361,11 +380,11 @@ async def test_put_resource_new_file(client, test_config, entity_repository, sea
 
 
 @pytest.mark.asyncio
-async def test_put_resource_update_existing(client, test_config, entity_repository):
+async def test_put_resource_update_existing(client, project_config, entity_repository, project_url):
     """Test updating an existing file via PUT."""
     # Create an initial file and entity
     file_path = "visualizations/update-test.canvas"
-    full_path = Path(test_config.home) / file_path
+    full_path = Path(project_config.home) / file_path
     full_path.parent.mkdir(parents=True, exist_ok=True)
 
     initial_data = {
@@ -414,7 +433,9 @@ async def test_put_resource_update_existing(client, test_config, entity_reposito
     }
 
     # Execute PUT request to update
-    response = await client.put(f"/resource/{file_path}", json=json.dumps(updated_data, indent=2))
+    response = await client.put(
+        f"{project_url}/resource/{file_path}", json=json.dumps(updated_data, indent=2)
+    )
 
     # Verify response
     assert response.status_code == 200
