@@ -56,7 +56,7 @@ async def setup_test_note(entity_service, search_service) -> AsyncGenerator[dict
     }
 
 
-def test_write_note(cli_env, test_config):
+def test_write_note(cli_env, project_config, test_project):
     """Test write_note command with basic arguments."""
     result = runner.invoke(
         tool_app,
@@ -68,6 +68,32 @@ def test_write_note(cli_env, test_config):
             "This is a CLI test note",
             "--folder",
             "test",
+            "--project",
+            test_project.name,
+        ],
+    )
+    assert result.exit_code == 0
+
+    # Check for expected success message
+    assert "CLI Test Note" in result.stdout
+    assert "Created" in result.stdout or "Updated" in result.stdout
+    assert "permalink" in result.stdout
+
+
+def test_write_note_with_project_arg(cli_env, project_config, test_project):
+    """Test write_note command with basic arguments."""
+    result = runner.invoke(
+        tool_app,
+        [
+            "write-note",
+            "--project",
+            test_project.name,
+            "--title",
+            "CLI Test Note",
+            "--content",
+            "This is a CLI test note",
+            "--folder",
+            "test",
         ],
     )
     assert result.exit_code == 0
@@ -78,7 +104,7 @@ def test_write_note(cli_env, test_config):
     assert "permalink" in result.stdout
 
 
-def test_write_note_with_tags(cli_env, test_config):
+def test_write_note_with_tags(cli_env, project_config):
     """Test write_note command with tags."""
     result = runner.invoke(
         tool_app,
@@ -103,7 +129,7 @@ def test_write_note_with_tags(cli_env, test_config):
     assert "tag1, tag2" in result.stdout or "tag1" in result.stdout and "tag2" in result.stdout
 
 
-def test_write_note_from_stdin(cli_env, test_config, monkeypatch):
+def test_write_note_from_stdin(cli_env, project_config, monkeypatch):
     """Test write_note command reading from stdin.
 
     This test requires minimal mocking of stdin to simulate piped input.
@@ -135,7 +161,7 @@ def test_write_note_from_stdin(cli_env, test_config, monkeypatch):
     assert "permalink" in result.stdout
 
 
-def test_write_note_content_param_priority(cli_env, test_config):
+def test_write_note_content_param_priority(cli_env, project_config):
     """Test that content parameter has priority over stdin."""
     stdin_content = "This content from stdin should NOT be used"
     param_content = "This explicit content parameter should be used"
@@ -167,7 +193,7 @@ def test_write_note_content_param_priority(cli_env, test_config):
         assert "Created" in result.stdout or "Updated" in result.stdout
 
 
-def test_write_note_no_content(cli_env, test_config):
+def test_write_note_no_content(cli_env, project_config):
     """Test error handling when no content is provided."""
     # Mock stdin to appear as a terminal, not a pipe
     with patch("sys.stdin.isatty", return_value=True):
@@ -209,11 +235,11 @@ def test_read_note(cli_env, setup_test_note):
     # so we're not asserting their presence
 
 
-def test_search_basic(cli_env, setup_test_note):
+def test_search_basic(cli_env, setup_test_note, test_project):
     """Test basic search command."""
     result = runner.invoke(
         tool_app,
-        ["search-notes", "test observation"],
+        ["search-notes", "test observation", "--project", test_project.name],
     )
     assert result.exit_code == 0
 
@@ -267,12 +293,13 @@ def test_build_context(cli_env, setup_test_note):
 
     # Result should be JSON containing our test note
     context_result = json.loads(result.stdout)
-    assert len(context_result["primary_results"]) > 0
+    assert "results" in context_result
+    assert len(context_result["results"]) > 0
 
     # Primary results should include our test note
     found = False
-    for item in context_result["primary_results"]:
-        if item["permalink"] == permalink:
+    for item in context_result["results"]:
+        if item["primary_result"]["permalink"] == permalink:
             found = True
             break
 
@@ -308,23 +335,64 @@ def test_build_context_with_options(cli_env, setup_test_note):
     # Check that metadata reflects our options
     assert context_result["metadata"]["depth"] == 2
     timeframe = datetime.fromisoformat(context_result["metadata"]["timeframe"])
-    assert datetime.now() - timeframe <= timedelta(days=2)  # don't bother about timezones
+    assert datetime.now().astimezone() - timeframe <= timedelta(
+        days=2
+    )  # Compare timezone-aware datetimes
 
-    # Primary results should include our test note
+    # Results should include our test note
     found = False
-    for item in context_result["primary_results"]:
-        if item["permalink"] == permalink:
+    for item in context_result["results"]:
+        if item["primary_result"]["permalink"] == permalink:
             found = True
             break
 
     assert found, "Context did not include the test note"
 
 
+def test_build_context_string_depth_parameter(cli_env, setup_test_note):
+    """Test build_context command handles string depth parameter correctly."""
+    permalink = setup_test_note["permalink"]
+
+    # Test valid string depth parameter - Typer should convert it to int
+    result = runner.invoke(
+        tool_app,
+        [
+            "build-context",
+            f"memory://{permalink}",
+            "--depth",
+            "2",  # This is always a string from CLI
+        ],
+    )
+    assert result.exit_code == 0
+
+    # Result should be JSON containing our test note with correct depth
+    context_result = json.loads(result.stdout)
+    assert context_result["metadata"]["depth"] == 2
+
+    # Test invalid string depth parameter - should fail with Typer validation error
+    result = runner.invoke(
+        tool_app,
+        [
+            "build-context",
+            f"memory://{permalink}",
+            "--depth",
+            "invalid",
+        ],
+    )
+    assert result.exit_code == 2  # Typer exits with code 2 for parameter validation errors
+    # Typer should show a usage error for invalid integer
+    assert (
+        "invalid" in result.stderr
+        and "is not a valid" in result.stderr
+        and "integer" in result.stderr
+    )
+
+
 # The get-entity CLI command was removed when tools were refactored
 # into separate files with improved error handling
 
 
-def test_recent_activity(cli_env, setup_test_note):
+def test_recent_activity(cli_env, setup_test_note, test_project):
     """Test recent_activity command with defaults."""
     result = runner.invoke(
         tool_app,
@@ -332,22 +400,16 @@ def test_recent_activity(cli_env, setup_test_note):
     )
     assert result.exit_code == 0
 
-    # Result should be JSON containing recent activity
-    activity_result = json.loads(result.stdout)
-    assert "primary_results" in activity_result
-    assert "metadata" in activity_result
+    # Result should be human-readable string containing recent activity
+    output = result.stdout
+    assert "Recent Activity Summary" in output
+    assert "Most Active Project:" in output or "Other Active Projects:" in output
 
-    # Our test note should be in the recent activity
-    found = False
-    for item in activity_result["primary_results"]:
-        if "permalink" in item and setup_test_note["permalink"] == item["permalink"]:
-            found = True
-            break
-
-    assert found, "Recent activity did not include the test note"
+    # Our test note should be referenced in the output
+    assert setup_test_note["permalink"] in output or setup_test_note["title"] in output
 
 
-def test_recent_activity_with_options(cli_env, setup_test_note):
+def test_recent_activity_with_options(cli_env, setup_test_note, test_project):
     """Test recent_activity command with options."""
     result = runner.invoke(
         tool_app,
@@ -359,27 +421,17 @@ def test_recent_activity_with_options(cli_env, setup_test_note):
             "2",
             "--timeframe",
             "7d",
-            "--page",
-            "1",
-            "--page-size",
-            "20",
-            "--max-related",
-            "20",
         ],
     )
     assert result.exit_code == 0
 
-    # Result should be JSON containing recent activity
-    activity_result = json.loads(result.stdout)
+    # Result should be human-readable string containing recent activity
+    output = result.stdout
+    assert "Recent Activity Summary" in output
+    assert "Most Active Project:" in output or "Other Active Projects:" in output
 
-    # Check that requested entity types are included
-    entity_types = set()
-    for item in activity_result["primary_results"]:
-        if "type" in item:
-            entity_types.add(item["type"])
-
-    # Should find both entity and observation types
-    assert "entity" in entity_types or "observation" in entity_types
+    # Should include information about entities since we requested entity type
+    assert setup_test_note["permalink"] in output or setup_test_note["title"] in output
 
 
 def test_continue_conversation(cli_env, setup_test_note):
@@ -415,19 +467,19 @@ def test_continue_conversation_no_results(cli_env):
 
 
 @patch("basic_memory.services.initialization.initialize_database")
-def test_ensure_migrations_functionality(mock_initialize_database, test_config, monkeypatch):
+def test_ensure_migrations_functionality(mock_initialize_database, app_config, monkeypatch):
     """Test the database initialization functionality."""
     from basic_memory.services.initialization import ensure_initialization
 
     # Call the function
-    ensure_initialization(test_config)
+    ensure_initialization(app_config)
 
     # The underlying asyncio.run should call our mocked function
     mock_initialize_database.assert_called_once()
 
 
 @patch("basic_memory.services.initialization.initialize_database")
-def test_ensure_migrations_handles_errors(mock_initialize_database, test_config, monkeypatch):
+def test_ensure_migrations_handles_errors(mock_initialize_database, app_config, monkeypatch):
     """Test that initialization handles errors gracefully."""
     from basic_memory.services.initialization import ensure_initialization
 
@@ -435,6 +487,6 @@ def test_ensure_migrations_handles_errors(mock_initialize_database, test_config,
     mock_initialize_database.side_effect = Exception("Test error")
 
     # Call the function - should not raise exception
-    ensure_initialization(test_config)
+    ensure_initialization(app_config)
 
     # We're just making sure it doesn't crash by calling it
