@@ -6,9 +6,8 @@ import pytest
 from typer.testing import CliRunner
 
 from basic_memory.cli.app import app
-from basic_memory.cli.commands import import_claude_conversations as import_claude
-from basic_memory.config import config
-from basic_memory.markdown import EntityParser, MarkdownProcessor
+from basic_memory.cli.commands import import_claude_conversations  # noqa
+from basic_memory.config import get_project_config
 
 # Set up CLI runner
 runner = CliRunner()
@@ -50,31 +49,6 @@ def sample_conversations_json(tmp_path, sample_conversation):
     return json_file
 
 
-@pytest.mark.asyncio
-async def test_process_chat_json(tmp_path, sample_conversations_json):
-    """Test importing conversations from JSON."""
-    entity_parser = EntityParser(tmp_path)
-    processor = MarkdownProcessor(entity_parser)
-
-    results = await import_claude.process_conversations_json(
-        sample_conversations_json, tmp_path, processor
-    )
-
-    assert results["conversations"] == 1
-    assert results["messages"] == 2
-
-    # Check conversation file
-    conv_path = tmp_path / "20250105-test-conversation.md"
-    assert conv_path.exists()
-    content = conv_path.read_text(encoding="utf-8")
-
-    # Check content formatting
-    assert "### Human" in content
-    assert "Hello, this is a test" in content
-    assert "### Assistant" in content
-    assert "Response to test" in content
-
-
 def test_import_conversations_command_file_not_found(tmp_path):
     """Test error handling for nonexistent file."""
     nonexistent = tmp_path / "nonexistent.json"
@@ -112,6 +86,7 @@ def test_import_conversations_command_invalid_json(tmp_path):
 def test_import_conversations_with_custom_folder(tmp_path, sample_conversations_json, monkeypatch):
     """Test import with custom conversations folder."""
     # Set up test environment
+    config = get_project_config()
     config.home = tmp_path
     conversations_folder = "chats"
 
@@ -130,7 +105,7 @@ def test_import_conversations_with_custom_folder(tmp_path, sample_conversations_
     assert result.exit_code == 0
 
     # Check files in custom folder
-    conv_path = tmp_path / conversations_folder / "20250105-test-conversation.md"
+    conv_path = tmp_path / conversations_folder / "20250105-Test_Conversation.md"
     assert conv_path.exists()
 
 
@@ -160,6 +135,7 @@ def test_import_conversation_with_attachments(tmp_path):
     with open(json_file, "w", encoding="utf-8") as f:
         json.dump([conversation], f)
 
+    config = get_project_config()
     # Set up environment
     config.home = tmp_path
 
@@ -168,8 +144,60 @@ def test_import_conversation_with_attachments(tmp_path):
     assert result.exit_code == 0
 
     # Check attachment formatting
-    conv_path = tmp_path / "conversations/20250105-test-with-attachments.md"
+    conv_path = tmp_path / "conversations/20250105-Test_With_Attachments.md"
     content = conv_path.read_text(encoding="utf-8")
     assert "**Attachment: test.txt**" in content
     assert "```" in content
     assert "Test file content" in content
+
+
+def test_import_conversation_with_none_text_values(tmp_path):
+    """Test importing conversation with None text values in content array (issue #236)."""
+    # Create conversation with None text values
+    conversation = {
+        "uuid": "test-uuid",
+        "name": "Test With None Text",
+        "created_at": "2025-01-05T20:55:32.499880+00:00",
+        "updated_at": "2025-01-05T20:56:39.477600+00:00",
+        "chat_messages": [
+            {
+                "uuid": "msg-1",
+                "text": None,
+                "sender": "human",
+                "created_at": "2025-01-05T20:55:32.499880+00:00",
+                "content": [
+                    {"type": "text", "text": "Valid text here"},
+                    {"type": "text", "text": None},  # This caused the TypeError
+                    {"type": "text", "text": "More valid text"},
+                ],
+            },
+            {
+                "uuid": "msg-2",
+                "text": None,
+                "sender": "assistant",
+                "created_at": "2025-01-05T20:55:40.123456+00:00",
+                "content": [
+                    {"type": "text", "text": None},  # All None case
+                    {"type": "text", "text": None},
+                ],
+            },
+        ],
+    }
+
+    json_file = tmp_path / "with_none_text.json"
+    with open(json_file, "w", encoding="utf-8") as f:
+        json.dump([conversation], f)
+
+    config = get_project_config()
+    config.home = tmp_path
+
+    # Run import - should not fail with TypeError
+    result = runner.invoke(app, ["import", "claude", "conversations", str(json_file)])
+    assert result.exit_code == 0
+
+    # Check that valid text is preserved and None values are filtered out
+    conv_path = tmp_path / "conversations/20250105-Test_With_None_Text.md"
+    assert conv_path.exists()
+    content = conv_path.read_text(encoding="utf-8")
+    assert "Valid text here" in content
+    assert "More valid text" in content
