@@ -6,8 +6,8 @@ import pytest
 from typer.testing import CliRunner
 
 from basic_memory.cli.app import import_app
-from basic_memory.cli.commands import import_memory_json
-from basic_memory.markdown import EntityParser, MarkdownProcessor
+from basic_memory.cli.commands import import_memory_json  # noqa
+from basic_memory.markdown import MarkdownProcessor
 
 # Set up CLI runner
 runner = CliRunner()
@@ -42,26 +42,6 @@ def sample_json_file(tmp_path, sample_entities):
     return json_file
 
 
-@pytest.mark.asyncio
-async def test_process_memory_json(tmp_path, sample_json_file):
-    """Test importing entities from JSON."""
-    entity_parser = EntityParser(tmp_path)
-    processor = MarkdownProcessor(entity_parser)
-
-    results = await import_memory_json.process_memory_json(sample_json_file, tmp_path, processor)
-
-    assert results["entities"] == 1
-    assert results["relations"] == 1
-
-    # Check file was created
-    entity_file = tmp_path / "test/test_entity.md"
-    assert entity_file.exists()
-    content = entity_file.read_text(encoding="utf-8")
-    assert "Test observation 1" in content
-    assert "Test observation 2" in content
-    assert "test_relation [[related_entity]]" in content
-
-
 @pytest.mark.asyncio
 async def test_get_markdown_processor(tmp_path, monkeypatch):
     """Test getting markdown processor."""
@@ -133,3 +113,43 @@ def test_import_json_command_handle_old_format(tmp_path):
     result = runner.invoke(import_app, ["memory-json", str(json_file)])
     assert result.exit_code == 0
     assert "Import complete" in result.output
+
+
+def test_import_json_command_missing_name_key(tmp_path):
+    """Test handling JSON with missing 'name' key using 'id' instead."""
+    # Create JSON with id instead of name (common in Knowledge Graph Memory Server)
+    data_with_id = [
+        {
+            "type": "entity",
+            "id": "test_entity_id",
+            "entityType": "test",
+            "observations": ["Test observation with id"],
+        },
+        {
+            "type": "entity",
+            "entityName": "test_entity_2",
+            "entityType": "test",
+            "observations": ["Test observation with entityName"],
+        },
+        {
+            "type": "entity",
+            "name": "test_entity_title",
+            "entityType": "test",
+            "observations": ["Test observation with name"],
+        },
+    ]
+
+    json_file = tmp_path / "missing_name.json"
+    with open(json_file, "w", encoding="utf-8") as f:
+        for item in data_with_id:
+            f.write(json.dumps(item) + "\n")
+
+    # Set up test environment
+    monkeypatch = pytest.MonkeyPatch()
+    monkeypatch.setenv("HOME", str(tmp_path))
+
+    # Run import - should not fail even without 'name' key
+    result = runner.invoke(import_app, ["memory-json", str(json_file)])
+    assert result.exit_code == 0
+    assert "Import complete" in result.output
+    assert "Created 3 entities" in result.output
