@@ -1,30 +1,35 @@
 """Common test fixtures."""
 
+from dataclasses import dataclass
 from datetime import datetime, timezone
 from pathlib import Path
 from textwrap import dedent
 from typing import AsyncGenerator
 
+import os
 import pytest
 import pytest_asyncio
-from loguru import logger
 from sqlalchemy.ext.asyncio import AsyncEngine, AsyncSession, async_sessionmaker
 
 from basic_memory import db
-from basic_memory.config import ProjectConfig
+from basic_memory.config import ProjectConfig, BasicMemoryConfig, ConfigManager
 from basic_memory.db import DatabaseType
 from basic_memory.markdown import EntityParser
 from basic_memory.markdown.markdown_processor import MarkdownProcessor
 from basic_memory.models import Base
 from basic_memory.models.knowledge import Entity
+from basic_memory.models.project import Project
 from basic_memory.repository.entity_repository import EntityRepository
 from basic_memory.repository.observation_repository import ObservationRepository
+from basic_memory.repository.project_repository import ProjectRepository
 from basic_memory.repository.relation_repository import RelationRepository
 from basic_memory.repository.search_repository import SearchRepository
 from basic_memory.schemas.base import Entity as EntitySchema
 from basic_memory.services import (
     EntityService,
+    ProjectService,
 )
+from basic_memory.services.directory_service import DirectoryService
 from basic_memory.services.file_service import FileService
 from basic_memory.services.link_resolver import LinkResolver
 from basic_memory.services.search_service import SearchService
@@ -32,31 +37,97 @@ from basic_memory.sync.sync_service import SyncService
 from basic_memory.sync.watch_service import WatchService
 
 
-@pytest_asyncio.fixture
+@pytest.fixture
 def anyio_backend():
     return "asyncio"
 
 
-@pytest_asyncio.fixture
-def test_config(tmp_path) -> ProjectConfig:
-    """Test configuration using in-memory DB."""
-    config = ProjectConfig(
-        project="test-project",
-    )
-    config.home = tmp_path
+@pytest.fixture
+def project_root() -> Path:
+    return Path(__file__).parent.parent
 
-    (tmp_path / config.home.name).mkdir(parents=True, exist_ok=True)
-    logger.info(f"project config home: {config.home}")
-    return config
+
+@pytest.fixture
+def config_home(tmp_path, monkeypatch) -> Path:
+    # Patch HOME environment variable for the duration of the test
+    monkeypatch.setenv("HOME", str(tmp_path))
+    # On Windows, also set USERPROFILE
+    if os.name == "nt":
+        monkeypatch.setenv("USERPROFILE", str(tmp_path))
+    # Set BASIC_MEMORY_HOME to the test directory
+    monkeypatch.setenv("BASIC_MEMORY_HOME", str(tmp_path / "basic-memory"))
+    return tmp_path
+
+
+@pytest.fixture(scope="function", autouse=True)
+def app_config(config_home, tmp_path, monkeypatch) -> BasicMemoryConfig:
+    """Create test app configuration."""
+    # Create a basic config without depending on test_project to avoid circular dependency
+    projects = {"test-project": str(config_home)}
+    app_config = BasicMemoryConfig(
+        env="test",
+        projects=projects,
+        default_project="test-project",
+        update_permalinks_on_move=True,
+    )
+
+    return app_config
+
+
+@pytest.fixture(autouse=True)
+def config_manager(
+    app_config: BasicMemoryConfig, project_config: ProjectConfig, config_home: Path, monkeypatch
+) -> ConfigManager:
+    # Invalidate config cache to ensure clean state for each test
+    from basic_memory import config as config_module
+
+    config_module._CONFIG_CACHE = None
+
+    # Create a new ConfigManager that uses the test home directory
+    config_manager = ConfigManager()
+    # Update its paths to use the test directory
+    config_manager.config_dir = config_home / ".basic-memory"
+    config_manager.config_file = config_manager.config_dir / "config.json"
+    config_manager.config_dir.mkdir(parents=True, exist_ok=True)
+
+    # Ensure the config file is written to disk
+    config_manager.save_config(app_config)
+    return config_manager
+
+
+@pytest.fixture(scope="function", autouse=True)
+def project_config(test_project):
+    """Create test project configuration."""
+
+    project_config = ProjectConfig(
+        name=test_project.name,
+        home=Path(test_project.path),
+    )
+
+    return project_config
+
+
+@dataclass
+class TestConfig:
+    config_home: Path
+    project_config: ProjectConfig
+    app_config: BasicMemoryConfig
+    config_manager: ConfigManager
+
+
+@pytest.fixture
+def test_config(config_home, project_config, app_config, config_manager) -> TestConfig:
+    """All test configuration fixtures"""
+    return TestConfig(config_home, project_config, app_config, config_manager)
 
 
 @pytest_asyncio.fixture(scope="function")
 async def engine_factory(
-    test_config,
+    app_config,
 ) -> AsyncGenerator[tuple[AsyncEngine, async_sessionmaker[AsyncSession]], None]:
-    """Create engine and session factory using in-memory SQLite database."""
+    """Create an engine and session factory using an in-memory SQLite database."""
     async with db.engine_session_factory(
-        db_path=test_config.database_path, db_type=DatabaseType.MEMORY
+        db_path=app_config.database_path, db_type=DatabaseType.MEMORY
     ) as (engine, session_maker):
         # Create all tables for the DB the engine is connected to
         async with engine.begin() as conn:
@@ -72,26 +143,58 @@ async def session_maker(engine_factory) -> async_sessionmaker[AsyncSession]:
     return session_maker
 
 
+## Repositories
+
+
 @pytest_asyncio.fixture(scope="function")
-async def entity_repository(session_maker: async_sessionmaker[AsyncSession]) -> EntityRepository:
-    """Create an EntityRepository instance."""
-    return EntityRepository(session_maker)
+async def entity_repository(
+    session_maker: async_sessionmaker[AsyncSession], test_project: Project
+) -> EntityRepository:
+    """Create an EntityRepository instance with project context."""
+    return EntityRepository(session_maker, project_id=test_project.id)
 
 
 @pytest_asyncio.fixture(scope="function")
 async def observation_repository(
-    session_maker: async_sessionmaker[AsyncSession],
+    session_maker: async_sessionmaker[AsyncSession], test_project: Project
 ) -> ObservationRepository:
-    """Create an ObservationRepository instance."""
-    return ObservationRepository(session_maker)
+    """Create an ObservationRepository instance with project context."""
+    return ObservationRepository(session_maker, project_id=test_project.id)
 
 
 @pytest_asyncio.fixture(scope="function")
 async def relation_repository(
-    session_maker: async_sessionmaker[AsyncSession],
+    session_maker: async_sessionmaker[AsyncSession], test_project: Project
 ) -> RelationRepository:
-    """Create a RelationRepository instance."""
-    return RelationRepository(session_maker)
+    """Create a RelationRepository instance with project context."""
+    return RelationRepository(session_maker, project_id=test_project.id)
+
+
+@pytest_asyncio.fixture(scope="function")
+async def project_repository(
+    session_maker: async_sessionmaker[AsyncSession],
+) -> ProjectRepository:
+    """Create a ProjectRepository instance."""
+    return ProjectRepository(session_maker)
+
+
+@pytest_asyncio.fixture(scope="function")
+async def test_project(config_home, engine_factory) -> Project:
+    """Create a test project to be used as context for other repositories."""
+    project_data = {
+        "name": "test-project",
+        "description": "Project used as context for tests",
+        "path": str(config_home),
+        "is_active": True,
+        "is_default": True,  # Explicitly set as the default project (for cli operations)
+    }
+    engine, session_maker = engine_factory
+    project_repository = ProjectRepository(session_maker)
+    project = await project_repository.create(project_data)
+    return project
+
+
+## Services
 
 
 @pytest_asyncio.fixture
@@ -102,6 +205,7 @@ async def entity_service(
     entity_parser: EntityParser,
     file_service: FileService,
     link_resolver: LinkResolver,
+    app_config: BasicMemoryConfig,
 ) -> EntityService:
     """Create EntityService."""
     return EntityService(
@@ -111,13 +215,16 @@ async def entity_service(
         relation_repository=relation_repository,
         file_service=file_service,
         link_resolver=link_resolver,
+        app_config=app_config,
     )
 
 
 @pytest.fixture
-def file_service(test_config: ProjectConfig, markdown_processor: MarkdownProcessor) -> FileService:
+def file_service(
+    project_config: ProjectConfig, markdown_processor: MarkdownProcessor
+) -> FileService:
     """Create FileService instance."""
-    return FileService(test_config.home, markdown_processor)
+    return FileService(project_config.home, markdown_processor)
 
 
 @pytest.fixture
@@ -133,16 +240,17 @@ def link_resolver(entity_repository: EntityRepository, search_service: SearchSer
 
 
 @pytest.fixture
-def entity_parser(test_config):
+def entity_parser(project_config):
     """Create parser instance."""
-    return EntityParser(test_config.home)
+    return EntityParser(project_config.home)
 
 
 @pytest_asyncio.fixture
 async def sync_service(
-    test_config: ProjectConfig,
+    app_config: BasicMemoryConfig,
     entity_service: EntityService,
     entity_parser: EntityParser,
+    project_repository: ProjectRepository,
     entity_repository: EntityRepository,
     relation_repository: RelationRepository,
     search_service: SearchService,
@@ -150,8 +258,9 @@ async def sync_service(
 ) -> SyncService:
     """Create sync service for testing."""
     return SyncService(
-        config=test_config,
+        app_config=app_config,
         entity_service=entity_service,
+        project_repository=project_repository,
         entity_repository=entity_repository,
         relation_repository=relation_repository,
         entity_parser=entity_parser,
@@ -161,9 +270,17 @@ async def sync_service(
 
 
 @pytest_asyncio.fixture
-async def search_repository(session_maker):
-    """Create SearchRepository instance"""
-    return SearchRepository(session_maker)
+async def directory_service(entity_repository, project_config) -> DirectoryService:
+    """Create directory service for testing."""
+    return DirectoryService(
+        entity_repository=entity_repository,
+    )
+
+
+@pytest_asyncio.fixture
+async def search_repository(session_maker, test_project: Project):
+    """Create SearchRepository instance with project context"""
+    return SearchRepository(session_maker, project_id=test_project.id)
 
 
 @pytest_asyncio.fixture(autouse=True)
@@ -187,6 +304,7 @@ async def search_service(
 async def sample_entity(entity_repository: EntityRepository) -> Entity:
     """Create a sample entity for testing."""
     entity_data = {
+        "project_id": entity_repository.project_id,
         "title": "Test Entity",
         "entity_type": "test",
         "permalink": "test/test-entity",
@@ -198,6 +316,14 @@ async def sample_entity(entity_repository: EntityRepository) -> Entity:
     return await entity_repository.create(entity_data)
 
 
+@pytest_asyncio.fixture
+async def project_service(
+    project_repository: ProjectRepository,
+) -> ProjectService:
+    """Create ProjectService with repository."""
+    return ProjectService(repository=project_repository)
+
+
 @pytest_asyncio.fixture
 async def full_entity(sample_entity, entity_repository, file_service, entity_service) -> Entity:
     """Create a search test entity."""
@@ -212,7 +338,7 @@ async def full_entity(sample_entity, entity_repository, file_service, entity_ser
                 ## Observations
                 - [tech] Tech note
                 - [design] Design note
-                
+
                 ## Relations
                 - out1 [[Test Entity]]
                 - out2 [[Test Entity]]
@@ -314,21 +440,21 @@ async def test_graph(
     }
 
 
-@pytest_asyncio.fixture
-def watch_service(sync_service, file_service, test_config):
-    return WatchService(sync_service=sync_service, file_service=file_service, config=test_config)
+@pytest.fixture
+def watch_service(app_config: BasicMemoryConfig, project_repository) -> WatchService:
+    return WatchService(app_config=app_config, project_repository=project_repository)
 
 
 @pytest.fixture
-def test_files(test_config) -> dict[str, Path]:
+def test_files(project_config, project_root) -> dict[str, Path]:
     """Copy test files into the project directory.
 
     Returns a dict mapping file names to their paths in the project dir.
     """
     # Source files relative to tests directory
     source_files = {
-        "pdf": Path("tests/Non-MarkdownFileSupport.pdf"),
-        "image": Path("tests/Screenshot.png"),
+        "pdf": Path(project_root / "tests/Non-MarkdownFileSupport.pdf"),
+        "image": Path(project_root / "tests/Screenshot.png"),
     }
 
     # Create copies in temp project directory
@@ -338,7 +464,7 @@ def test_files(test_config) -> dict[str, Path]:
         content = src_path.read_bytes()
 
         # Create destination path and ensure parent dirs exist
-        dest_path = test_config.home / src_path.name
+        dest_path = project_config.home / src_path.name
         dest_path.parent.mkdir(parents=True, exist_ok=True)
 
         # Write file
@@ -349,7 +475,7 @@ def test_files(test_config) -> dict[str, Path]:
 
 
 @pytest_asyncio.fixture
-async def synced_files(sync_service, test_config, test_files):
+async def synced_files(sync_service, project_config, test_files):
     # Initial sync - should create forward reference
-    await sync_service.sync(test_config.home)
+    await sync_service.sync(project_config.home)
     return test_files
