@@ -16,7 +16,7 @@ from basic_memory.mcp.tools.read_content import (
 
 
 @pytest.mark.asyncio
-async def test_read_file_text_file(app, synced_files):
+async def test_read_file_text_file(app, synced_files, test_project):
     """Test reading a text file.
 
     Should:
@@ -25,7 +25,8 @@ async def test_read_file_text_file(app, synced_files):
     - Include correct metadata
     """
     # First create a text file via notes
-    result = await write_note(
+    result = await write_note.fn(
+        project=test_project.name,
         title="Text Resource",
         folder="test",
         content="This is a test text resource",
@@ -34,7 +35,7 @@ async def test_read_file_text_file(app, synced_files):
     assert result is not None
 
     # Now read it as a resource
-    response = await read_content("test/text-resource")
+    response = await read_content.fn("test/text-resource", project=test_project.name)
 
     assert response["type"] == "text"
     assert "This is a test text resource" in response["text"]
@@ -43,7 +44,7 @@ async def test_read_file_text_file(app, synced_files):
 
 
 @pytest.mark.asyncio
-async def test_read_content_file_path(app, synced_files):
+async def test_read_content_file_path(app, synced_files, test_project):
     """Test reading a text file.
 
     Should:
@@ -52,7 +53,8 @@ async def test_read_content_file_path(app, synced_files):
     - Include correct metadata
     """
     # First create a text file via notes
-    result = await write_note(
+    result = await write_note.fn(
+        project=test_project.name,
         title="Text Resource",
         folder="test",
         content="This is a test text resource",
@@ -61,7 +63,7 @@ async def test_read_content_file_path(app, synced_files):
     assert result is not None
 
     # Now read it as a resource
-    response = await read_content("test/Text Resource.md")
+    response = await read_content.fn("test/Text Resource.md", project=test_project.name)
 
     assert response["type"] == "text"
     assert "This is a test text resource" in response["text"]
@@ -70,7 +72,7 @@ async def test_read_content_file_path(app, synced_files):
 
 
 @pytest.mark.asyncio
-async def test_read_file_image_file(app, synced_files):
+async def test_read_file_image_file(app, synced_files, test_project):
     """Test reading an image file.
 
     Should:
@@ -82,7 +84,7 @@ async def test_read_file_image_file(app, synced_files):
     image_path = synced_files["image"].name
 
     # Read it as a resource
-    response = await read_content(image_path)
+    response = await read_content.fn(image_path, project=test_project.name)
 
     assert response["type"] == "image"
     assert response["source"]["type"] == "base64"
@@ -99,7 +101,7 @@ async def test_read_file_image_file(app, synced_files):
 
 
 @pytest.mark.asyncio
-async def test_read_file_pdf_file(app, synced_files):
+async def test_read_file_pdf_file(app, synced_files, test_project):
     """Test reading a PDF file.
 
     Should:
@@ -110,7 +112,7 @@ async def test_read_file_pdf_file(app, synced_files):
     pdf_path = synced_files["pdf"].name
 
     # Read it as a resource
-    response = await read_content(pdf_path)
+    response = await read_content.fn(pdf_path, project=test_project.name)
 
     assert response["type"] == "document"
     assert response["source"]["type"] == "base64"
@@ -123,17 +125,18 @@ async def test_read_file_pdf_file(app, synced_files):
 
 
 @pytest.mark.asyncio
-async def test_read_file_not_found(app):
+async def test_read_file_not_found(app, test_project):
     """Test trying to read a non-existent"""
     with pytest.raises(ToolError, match="Resource not found"):
-        await read_content("does-not-exist")
+        await read_content.fn("does-not-exist", project=test_project.name)
 
 
 @pytest.mark.asyncio
-async def test_read_file_memory_url(app, synced_files):
+async def test_read_file_memory_url(app, synced_files, test_project):
     """Test reading a resource using a memory:// URL."""
     # Create a text file via notes
-    await write_note(
+    await write_note.fn(
+        project=test_project.name,
         title="Memory URL Test",
         folder="test",
         content="Testing memory:// URL handling for resources",
@@ -141,7 +144,7 @@ async def test_read_file_memory_url(app, synced_files):
 
     # Read it with a memory:// URL
     memory_url = "memory://test/memory-url-test"
-    response = await read_content(memory_url)
+    response = await read_content.fn(memory_url, project=test_project.name)
 
     assert response["type"] == "text"
     assert "Testing memory:// URL handling for resources" in response["text"]
@@ -194,7 +197,7 @@ async def test_image_optimization_functions(app):
 
 
 @pytest.mark.asyncio
-async def test_image_conversion(app, synced_files):
+async def test_image_conversion(app, synced_files, test_project):
     """Test reading an image and verify conversion works.
 
     Should:
@@ -205,7 +208,7 @@ async def test_image_conversion(app, synced_files):
     image_path = synced_files["image"].name
 
     # Test reading the resource
-    response = await read_content(image_path)
+    response = await read_content.fn(image_path, project=test_project.name)
 
     assert response["type"] == "image"
     assert response["source"]["media_type"] == "image/jpeg"
