@@ -2,7 +2,6 @@
 
 import pytest
 
-from basic_memory import file_utils
 from basic_memory.file_utils import compute_checksum, write_file_atomic
 
 
@@ -56,8 +55,11 @@ async def test_write_utf8_characters(tmp_path):
 
 
 @pytest.mark.asyncio
-async def test_frontmatter_with_utf8(tmp_path):
+async def test_frontmatter_with_utf8(tmp_path, sync_service):
     """Test handling of frontmatter with UTF-8 characters."""
+    # Use FileService from sync_service
+    file_service = sync_service.file_service
+
     # Create a test file with frontmatter containing UTF-8
     test_path = tmp_path / "frontmatter_utf8.md"
 
@@ -65,7 +67,7 @@ async def test_frontmatter_with_utf8(tmp_path):
     content = """---
 title: UTF-8 测试文件 (Test File)
 author: José García
-keywords: 
+keywords:
   - тестирование
   - 테스트
   - 测试
@@ -79,8 +81,8 @@ This file has UTF-8 characters in the frontmatter.
     # Write the file
     await write_file_atomic(test_path, content)
 
-    # Update frontmatter with more UTF-8
-    await file_utils.update_frontmatter(
+    # Update frontmatter with more UTF-8 using FileService
+    await file_service.update_frontmatter(
         test_path,
         {
             "description": "这是一个测试文件 (This is a test file)",
@@ -103,9 +105,9 @@ This file has UTF-8 characters in the frontmatter.
 
 
 @pytest.mark.asyncio
-async def test_utf8_in_entity_sync(sync_service, test_config):
+async def test_utf8_in_entity_sync(sync_service, project_config):
     """Test syncing an entity with UTF-8 content."""
-    project_dir = test_config.home
+    project_dir = project_config.home
 
     # Create a test file with UTF-8 characters
     test_file = project_dir / "utf8_entity.md"
@@ -130,7 +132,7 @@ permalink: i18n/utf8-document
     test_file.write_text(utf8_content, encoding="utf-8")
 
     # Sync the file
-    await sync_service.sync(test_config.home)
+    await sync_service.sync(project_config.home)
 
     # Verify entity was created
     entity = await sync_service.entity_service.get_by_permalink("i18n/utf8-document")
@@ -157,7 +159,7 @@ permalink: i18n/utf8-document
 
 
 @pytest.mark.asyncio
-async def test_write_file_service_utf8(sync_service, test_config):
+async def test_write_file_service_utf8(sync_service, project_config):
     """Test FileService handling of UTF-8 content."""
     file_service = sync_service.file_service
 
